(* Delphi Dialog
   Passwort-Abfrage
   ================
   Design hnlich wie Datei-Dialog unter Windows 2000/XP

    Dr. J. Rathlev, D-24222 Schwentinental (kontakt(a)rathlev-home.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.
    
   Vers. 1 - Dez. 2006
   letzte nderung: Okt. 2011
   *)

unit PwdDlg;

interface

uses Winapi.Windows, System.SysUtils, System.Classes, Vcl.Graphics, Vcl.Forms,
  Vcl.Controls, Vcl.StdCtrls, Vcl.Buttons, Vcl.ExtCtrls;

type
  TPasswordDialog = class(TForm)
    Label1: TLabel;
    edtPwd: TEdit;
    lblPrompt: TLabel;
    CancelBtn: TBitBtn;
    OKBtn: TBitBtn;
    btnSkip: TBitBtn;
    gbEncrypt: TGroupBox;
    rbEnc128: TRadioButton;
    rbEnc256: TRadioButton;
    rbEncAuto: TRadioButton;
    pnTop: TPanel;
    pnInput: TPanel;
    pnBottom: TPanel;
    procedure FormCreate(Sender: TObject);
  private
    { Private-Deklarationen }
    Hgt : integer;
  public
    { Public-Deklarationen }
    function Execute (const Title,Prompt : string; Skip,Enc  : boolean;
                      var Pwd : AnsiString; var EncMode  : integer) : TModalResult;  overload;
    function Execute (const Title,Prompt : string; var Pwd : AnsiString) : TModalResult;  overload;
  end;

// Result:  Skip = mrYes, Ok = mrOK, Cancel = mrCancel
function ReadPassword (const Title,Prompt : string; Skip,Enc : boolean;
                       var Pwd : AnsiString; var EncMode  : integer) : TModalResult; overload;

function ReadPassword (const Title,Prompt : string; Skip : boolean;
                       var Pwd : AnsiString) : TModalResult; overload;

var
  PasswordDialog: TPasswordDialog;

implementation

{$R *.dfm}

uses GnuGetText, WinUtils;

{------------------------------------------------------------------- }
procedure TPasswordDialog.FormCreate(Sender: TObject);
begin
  TranslateComponent (self,'dialogs');
//  AdjustClientSize(self,CancelBtn);
  Hgt:=gbEncrypt.Height;
  end;

{ ------------------------------------------------------------------- }
(* Passworteingabe, Ergebnis: mrOK bei "ok", mrYes bei "skip" *)
function TPasswordDialog.Execute (const Title,Prompt : string;
                                  Skip,Enc     : boolean;
                                  var Pwd      : AnsiString;
                                  var EncMode  : integer) : TModalResult;
var
  h : integer;
begin
  Caption:=Title;
  lblPrompt.Caption:=Prompt;
  pnTop.Height:=lblPrompt.Height+10;
  edtPwd.Text:=Pwd;
  btnSkip.Visible:=Skip;
  ActiveControl:=edtPwd;
  with gbEncrypt do begin
    Visible:=Enc;
    end;
  h:=pnTop.Height+pnInput.Height+pnBottom.Height;
  if Enc then ClientHeight:=h+Hgt else ClientHeight:=h;
  case Encmode of
  1 : rbEnc128.Checked:=true;
  2 : rbEnc256.Checked:=true;
  else  rbEncAuto.Checked:=true;
    end;
  Result:=ShowModal;
  if Result=mrOk then begin
    Pwd:=edtPwd.Text;
    if Enc then begin
      if rbEncAuto.Checked then EncMode:=0
      else if rbEnc128.Checked then EncMode:=1 else EncMode:=3;
      end;
    end;
  end;

function TPasswordDialog.Execute (const Title,Prompt : string;
                                  var Pwd      : AnsiString) : TModalResult;
var
  n : integer;
begin
  Result:=Execute(Title,Prompt,false,false,Pwd,n);
  end;

function ReadPassword (const Title,Prompt : string;
                       Skip,Enc     : boolean;
                       var Pwd      : AnsiString;
                       var EncMode  : integer) : TModalResult;
begin
  if not assigned(PasswordDialog) then PasswordDialog:=TPasswordDialog.Create(Application);
  with PasswordDialog do begin
    Result:=Execute(Title,Prompt,Skip,Enc,Pwd,EncMode);
    Release;
    end;
  PasswordDialog:=nil;
  end;

function ReadPassword (const Title,Prompt : string;
                       Skip         : boolean;
                       var Pwd      : AnsiString) : TModalResult;
var
  n : integer;
begin
  Result:=ReadPassword (Title,Prompt,Skip,false,Pwd,n);
  end;

end.
